import React from 'react';
import classNames from 'classnames';
import { notifyDeprecation } from '../utils';
export const Section = ({ color, image, testId, wrapperClassName, className, children, neutral, muted, ...rest }) => {
    const classes = classNames('section', wrapperClassName === true ? className : wrapperClassName, {
        [`section-${color}`]: color,
        'section-image': image
    });
    if (neutral || muted) {
        notifyDeprecation(`Please use the prop "color" instead of the "${neutral ? 'neutral' : 'muted'}" for the Section component.`);
    }
    // have them separated from the classes above or these will conflict with the color prop
    // concatenate them at the end. Worst case a duplicate class will appear
    const deprecatedClasses = classNames({
        'section-neutral': neutral,
        'section-muted': muted
    });
    const innerClasses = classNames('section-content', className);
    const styleClass = {
        backgroundImageClass: image ? { backgroundImage: `url(${image})` } : {}
    };
    const finalWrapperClassName = classNames(classes, deprecatedClasses);
    return (React.createElement("div", { className: finalWrapperClassName, style: styleClass.backgroundImageClass, "data-testid": testId, ...rest },
        React.createElement("div", { className: innerClasses }, children)));
};
//# sourceMappingURL=Section.js.map